.. Copyright 2016, 2017 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.bootstrap.forms
--------------------------------

.. sidebar:: Examples in this section

   - tutorial.addressbook2bootstrap

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. automodule:: reahl.web.bootstrap.forms


Forms and their layout
^^^^^^^^^^^^^^^^^^^^^^

Form
""""

.. autoclass:: Form
   :members:


NestedForm
""""""""""

.. autoclass:: NestedForm
   :members:


FormLayout
""""""""""

.. autoclass:: FormLayout
   :members:

InlineFormLayout
""""""""""""""""

.. autoclass:: InlineFormLayout
   :members:


GridFormLayout
""""""""""""""

.. autoclass:: GridFormLayout
   :members:


FieldSet
""""""""

.. autoclass:: FieldSet
   :members:


Inputs
^^^^^^

TextArea
""""""""

.. autoclass:: TextArea
   :members:


SelectInput
"""""""""""

.. autoclass:: SelectInput
   :members:
   

RadioButtonSelectInput
""""""""""""""""""""""

.. autoclass:: RadioButtonSelectInput
   :members:
   
TextInput
"""""""""

.. autoclass:: TextInput
   :members:

PasswordInput
"""""""""""""

.. autoclass:: PasswordInput
   :members:

PrimitiveCheckboxInput
""""""""""""""""""""""

.. autoclass:: PrimitiveCheckboxInput
   :members:

CheckboxInput
"""""""""""""

.. autoclass:: CheckboxInput
   :members:
   
Button
""""""

.. autoclass:: Button
   :members:

ButtonInput
"""""""""""

.. autoclass:: ButtonInput
   :members:

ButtonLayout
""""""""""""

.. autoclass:: ButtonLayout
   :members:
   

Label
"""""

.. autoclass:: Label
   :members:


StaticData
""""""""""

.. autoclass:: StaticData
   :members:


CueInput
""""""""

.. autoclass:: CueInput
   :members:


InputGroup
""""""""""

.. autoclass:: InputGroup
   :members:
